@@ -459,6 +459,26 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 	start <- 1
 	end <- length(speed$y)
 
+
+	#on "e", "ec", start on ground
+	if(! isInertial(encoderConfigurationName) && (eccon == "e" || eccon == "ec")) {
+		#if eccentric is undefined, find it
+		if(eccentric == 0) {
+			if(eccon == "e")
+				eccentric = 1:length(displacement)
+			else {  #(eccon=="ec")
+				phases=findECPhases(displacement,speed$y)
+				eccentric = phases$eccentric
+			}
+		}
+		
+		weight = mass * g
+		if(length(which(force[eccentric] <= weight)) > 0) {
+			landing = max(which(force[eccentric]<=weight))
+			start = landing
+		}
+	}
+
 	if( isPropulsive && ( eccon== "c" || eccon == "ec" ) )
 		end <- propulsiveEnd
 
@@ -702,7 +722,7 @@ getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel,
   if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
     force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel)
   } else if(encoderConfigurationName == "LINEARONPLANE"){
-    force <- (massBody + massExtra)*(a + g*sin(anglePush * pi / 180))
+    force <- (massBody + massExtra)*(accel + g*sin(anglePush * pi / 180))
   } else {
   	force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
   }
@@ -772,7 +792,7 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter
     angleSpeed = speed * 4 / diameter.m
     angleAccel = accel * 4 / diameter.m
     anglePush = 90 #TODO: send from C#
-    #The configuration covers horizontal, vertical and inclinated movements
+    #The configuration covers horizontal, vertical and inclined movements
     #If the movement is vertical g*sin(alpha) = g
     #If the movement is horizontal g*sin(alpha) = 0
 
@@ -876,9 +896,9 @@ getDisplacementInertial <- function(displacement, encoderConfigurationName, diam
               encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL"){
 	  displacement = displacement * diameter / diameterExt #displacement of the axis
 	} else if(encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALMOVPULLEY"){
-	  displacement = 2 * displacement #twice the displacement of the axis
+	  displacement = displacement / 2 #Half the displacement of the axis
 	} else if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY"){
-	  displacement = 2 * displacement * diameter / diameterExt #twice the displacement of the axis
+	  displacement = displacement * diameter /(2 * diameterExt) #Half the displacement of the axis
 	} else if(encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY"){
 	  displacementMeters = displacement / 1000 #mm -> m
 	  diameterMeters = diameter / 100 #cm -> m
@@ -975,8 +995,8 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 		lines((1:length(position))/1000,positionPerson/10,lty=1,lwd=2)
 
 		title(title, cex.main=1, font.main=1)
-		mtext(paste(translate("time"),"(s)"),side=1,adj=1,line=-1)
-		mtext(paste(translate("displacement"),"(cm)"),side=2,adj=1,line=-1)
+		mtext(paste(translateToPrint("time"),"(s)"),side=1,adj=1,line=-1)
+		mtext(paste(translateToPrint("displacement"),"(cm)"),side=2,adj=1,line=-1)
 	}
 	return(displacementPerson)
 }
