@@ -295,6 +295,43 @@ public class EncoderCurve
 		this.MaxForceT = maxForceT;
 	}
 
+	//http://stackoverflow.com/questions/894263/how-to-identify-if-a-string-is-a-number
+	//this does not check if decimal point is a different character (eg '.' or ',')
+	public bool IsNumberN() {
+		int num;
+		return int.TryParse(N, out num);
+	}
+
+	//check if last char is 'e' or 'c'
+	private bool isValidLastCharN() {
+		if(N.Length <= 1)
+			return false;
+		
+		char lastChar = N[N.Length-1];
+		if(lastChar == 'e' || lastChar == 'c')
+			return true;
+		
+		return false;
+	}
+	//check if it's "21c" or "15e"
+	public bool IsNumberNandEorC() {
+		if(N.Length <= 1)
+			return false;
+
+		int num;
+		if(int.TryParse(N.Substring(0, N.Length-1), out num) && isValidLastCharN())
+			return true;
+
+		return false;
+	}
+	//at least for RenderNAnalyze
+	public bool IsValidN() {
+		if (N == "AVG" || N == "SD" || IsNumberN() || IsNumberNandEorC())
+			return true;
+		return false;
+	}
+
+
 	public string ToCSV(string decimalSeparator) {
 		//latin:	2,3 ; 2,5
 		//non-latin:	2.3 , 2.5
