@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -73,7 +73,7 @@ class SqlitePersonSession : Sqlite
 			Util.ConvertToPoint(height) + ", " + Util.ConvertToPoint(weight) + ", " +
 			sportID + ", " + speciallityID + ", " + practice + ", '" + 
 			comments + "', '', '')"; 
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		//int myLast = dbcon.LastInsertRowId;
@@ -98,7 +98,7 @@ class SqlitePersonSession : Sqlite
 		       	" WHERE personID == " + personID + 
 			" AND sessionID == " + sessionID;
 		
-		//Log.WriteLine(dbcmd.CommandText.ToString());
+		//LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		SqliteDataReader reader;
@@ -125,7 +125,7 @@ class SqlitePersonSession : Sqlite
 			" WHERE personID == " + personID + 
 			"ORDER BY sessionID DESC LIMIT 1";
 		
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		SqliteDataReader reader;
@@ -153,7 +153,7 @@ class SqlitePersonSession : Sqlite
 			", practice = " + ps.Practice + 
 			", comments = '" + ps.Comments + 
 			"' WHERE uniqueID == " + ps.UniqueID;
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		Sqlite.Close();
 	}
@@ -167,7 +167,7 @@ class SqlitePersonSession : Sqlite
 			" WHERE personID = " + personID +
 			" AND sessionID = " + sessionID
 			;
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		Sqlite.Close();
 	}
@@ -178,7 +178,7 @@ class SqlitePersonSession : Sqlite
 		dbcmd.CommandText = "SELECT * FROM " + Constants.PersonSessionTable +
 			" WHERE personID == " + myPersonID + 
 			" AND sessionID == " + mySessionID ; 
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -198,22 +198,28 @@ class SqlitePersonSession : Sqlite
 	//then we search data in last sessionID
 	//this is used to know personSession attributes
 	//in a newly created person	
+	//This is like SqlitePerson.Select but this returns a PersonSession
 
-	//This is like SqlitePerson.Selectbut this returns a PersonSession
 	public static PersonSession Select(int personID, int sessionID)
 	{
+		return Select(false, personID, sessionID);
+	}
+	public static PersonSession Select(bool dbconOpened, int personID, int sessionID)
+	{
+		if( ! dbconOpened)
+			Sqlite.Open();
+
 		string tps = Constants.PersonSessionTable;
 			
 		string sessionIDString = " AND sessionID == " + sessionID;
 		if(sessionID == -1)
 			sessionIDString = " ORDER BY sessionID DESC limit 1";
 
-		Sqlite.Open();
 		dbcmd.CommandText = "SELECT * FROM " + tps +
 			" WHERE personID == " + personID + 
 			sessionIDString;
 		
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -234,25 +240,32 @@ class SqlitePersonSession : Sqlite
 		}
 		
 		reader.Close();
-		Sqlite.Close();
+		
+		if( ! dbconOpened)
+			Sqlite.Close();
+
 		return ps;
 	}
 	
 	//the difference between this select and others, is that this returns and ArrayList of Persons
 	//this is better than return the strings that can produce bugs in the future
 	//use this in the future:
-	public static ArrayList SelectCurrentSessionPersons(int sessionID) 
+	public static ArrayList SelectCurrentSessionPersons(int sessionID, bool returnPersonAndPSlist) 
 	{
 		string tp = Constants.PersonTable;
 		string tps = Constants.PersonSessionTable;
+			
+		string tpsString = "";
+		if(returnPersonAndPSlist)
+			tpsString = ", " + tps + ".* ";
 		
 		Sqlite.Open();
-		dbcmd.CommandText = "SELECT " + tp + ".*" +
+		dbcmd.CommandText = "SELECT " + tp + ".*" + tpsString +
 			" FROM " + tp + ", " + tps + 
 			" WHERE " + tps + ".sessionID == " + sessionID + 
 			" AND " + tp + ".uniqueID == " + tps + ".personID " + 
 			" ORDER BY upper(" + tp + ".name)";
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -269,86 +282,29 @@ class SqlitePersonSession : Sqlite
 					reader[6].ToString(),			//description
 					Convert.ToInt32(reader[9].ToString())	//serverUniqueID
 					);
-			myArray.Add (person);
+
+			if(returnPersonAndPSlist) {
+				PersonSession ps = new PersonSession(
+						Convert.ToInt32(reader[10].ToString()), 	//uniqueID
+						Convert.ToInt32(reader[11].ToString()), 	//personID
+						Convert.ToInt32(reader[12].ToString()), 	//sessionID
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[13].ToString())), //height
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[14].ToString())), //weight
+						Convert.ToInt32(reader[15].ToString()), 	//sportID
+						Convert.ToInt32(reader[16].ToString()), 	//speciallityID
+						Convert.ToInt32(reader[17].ToString()),	//practice
+						reader[18].ToString() 			//comments
+						);
+				myArray.Add(new PersonAndPS(person, ps));
+				
+			} else
+				myArray.Add (person);
 		}
 		reader.Close();
 		Sqlite.Close();
 		return myArray;
 	}
 	
-	/*
-	   try to use upper method:
-		public static ArrayList SelectCurrentSessionPersons(int sessionID) 
-		
-	public static string[] SelectCurrentSession(int sessionID, bool onlyIDAndName, bool reverse) 
-	{
-		string tp = Constants.PersonTable;
-		string tps = Constants.PersonSessionTable;
-		
-		Sqlite.Open();
-		dbcmd.CommandText = "SELECT " + tp + ".*, " + tps + ".weight, sport.name, speciallity.name " +
-			"FROM " + tp + ", " + tps + ", sport, speciallity " +
-			" WHERE " + tps + ".sessionID == " + sessionID + 
-			" AND " + tp + ".uniqueID == " + tps + ".personID " + 
-			" AND " + tp + ".sportID == sport.uniqueID " + 
-			" AND " + tp + ".speciallityID == speciallity.uniqueID " + 
-			" ORDER BY upper(" + tp + ".name)";
-		Log.WriteLine(dbcmd.CommandText.ToString());
-		dbcmd.ExecuteNonQuery();
-
-		SqliteDataReader reader;
-		reader = dbcmd.ExecuteReader();
-
-		ArrayList myArray = new ArrayList(2);
-
-		int count = new int();
-		count = 0;
-
-		while(reader.Read()) {
-			if(onlyIDAndName)
-				myArray.Add (reader[0].ToString() + ":" + reader[1].ToString() );
-			else {
-				string sportName = Catalog.GetString(reader[14].ToString());
-
-				string speciallityName = ""; //to solve a gettext bug (probably because speciallity undefined name is "")
-				if(reader[15].ToString() != "")
-					speciallityName = Catalog.GetString(reader[15].ToString());
-				string levelName = Catalog.GetString(Util.FindLevelName(Convert.ToInt32(reader[8])));
-
-				myArray.Add (
-						reader[0].ToString() + ":" + reader[1].ToString() + ":" + 	//id, name
-						reader[2].ToString() + ":" + 					//sex
-						UtilDate.FromSql(reader[3].ToString()).ToShortDateString() + ":" +	//dateborn
-						reader[4].ToString() + ":" + reader[13].ToString() + ":" + //height, weight (from personSessionWeight)
-						sportName + ":" + speciallityName + ":" + levelName + ":" +
-						reader[9].ToString()  //desc
-					    );
-			}
-			count ++;
-		}
-
-		reader.Close();
-		Sqlite.Close();
-
-		string [] myJumpers = new string[count];
-		
-		if(reverse) {
-			//show the results in the combo_sujeto_actual in reversed order, 
-			//then when we create a new person, this is the active, and this is shown 
-			//correctly in the combo_sujeto_actual
-			int count2 = count -1;
-			foreach (string line in myArray) {
-				myJumpers [count2--] = line;
-			}
-		} else {
-			int count2 = 0;
-			foreach (string line in myArray) {
-				myJumpers [count2++] = line;
-			}
-		}
-		return myJumpers;
-	}
-	*/
 	
 	public static void DeletePersonFromSessionAndTests(string sessionID, string personID)
 	{
@@ -468,7 +424,7 @@ class SqlitePersonSession : Sqlite
 
 		dbcmd.CommandText = "SELECT * FROM " + Constants.PersonSessionTable + 
 			" WHERE personID == " + personID;
-		//Log.WriteLine(dbcmd.CommandText.ToString());
+		//LogB.SQL(dbcmd.CommandText.ToString());
 		
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
@@ -479,7 +435,7 @@ class SqlitePersonSession : Sqlite
 		if (reader.Read()) {
 			exists = true;
 		}
-		//Log.WriteLine(string.Format("personID exists = {0}", exists.ToString()));
+		//LogB.SQL(string.Format("personID exists = {0}", exists.ToString()));
 
 		reader.Close();
 		
@@ -492,12 +448,34 @@ class SqlitePersonSession : Sqlite
 }
 
 
-//used to insert person and personSession in a single translation
+//used to insert person and personSession in a single translation when creating multiple persons
+//and used to to insert personSession in a single translation when recuperating multiple persons
 class SqlitePersonSessionTransaction : Sqlite
 {
+	List <Person> persons;
+	List <PersonSession> personSessions;
+	enum Modes { INSERT_PERSONS_MULTIPLE, RECUPERATE_PERSONS_MULTIPLE }
+	Modes mode;
+	
+	public SqlitePersonSessionTransaction(List <PersonSession> personSessions) 
+	{
+		this.personSessions = personSessions;
+		mode = Modes.RECUPERATE_PERSONS_MULTIPLE;
+		
+		doTransaction();
+	}
 	public SqlitePersonSessionTransaction(List <Person> persons, List <PersonSession> personSessions) 
 	{
-		Log.WriteLine("Starting transaction");
+		this.persons = persons;
+		this.personSessions = personSessions;
+		mode = Modes.INSERT_PERSONS_MULTIPLE;
+		
+		doTransaction();
+	}
+
+	public void doTransaction() 
+	{
+		LogB.SQL("Starting transaction");
 		Sqlite.Open();
 
 		using(SqliteTransaction tr = dbcon.BeginTransaction())
@@ -506,13 +484,15 @@ class SqlitePersonSessionTransaction : Sqlite
 			{
 				dbcmdTr.Transaction = tr;
 				
-				foreach(Person p in persons) {
-					dbcmdTr.CommandText = 
-						"INSERT INTO " + Constants.PersonTable +
-						" (uniqueID, name, sex, dateBorn, race, countryID, description, future1, future2, serverUniqueID) " + 
-						" VALUES (" + p.ToSQLInsertString() + ")";
-					Log.WriteLine(dbcmdTr.CommandText.ToString());
-					dbcmdTr.ExecuteNonQuery();
+				if(mode == Modes.INSERT_PERSONS_MULTIPLE) {
+					foreach(Person p in persons) {
+						dbcmdTr.CommandText = 
+							"INSERT INTO " + Constants.PersonTable +
+							" (uniqueID, name, sex, dateBorn, race, countryID, description, future1, future2, serverUniqueID) " + 
+							" VALUES (" + p.ToSQLInsertString() + ")";
+						LogB.SQL(dbcmdTr.CommandText.ToString());
+						dbcmdTr.ExecuteNonQuery();
+					}
 				}
 				foreach(PersonSession ps in personSessions) {
 					dbcmdTr.CommandText = 
@@ -520,7 +500,7 @@ class SqlitePersonSessionTransaction : Sqlite
 						"(uniqueID, personID, sessionID, height, weight, " + 
 						"sportID, speciallityID, practice, comments, future1, future2)" + 
 						" VALUES (" + ps.ToSQLInsertString() + ")";
-					Log.WriteLine(dbcmdTr.CommandText.ToString());
+					LogB.SQL(dbcmdTr.CommandText.ToString());
 					dbcmdTr.ExecuteNonQuery();
 				}
 			}
@@ -528,6 +508,6 @@ class SqlitePersonSessionTransaction : Sqlite
 		}
 
 		Sqlite.Close();
-		Log.WriteLine("Ended transaction");
+		LogB.SQL("Ended transaction");
 	}
 }
